import dotenv from "dotenv";
import { RouteManager, RouteMessages, createServer } from "server";
import { checkEnvironmentVariables } from "utils";
import ProxyRoute from "./routes/proxy";
import { initSecrets } from "./secrets";

dotenv.config(); // load .env file

// Check environment variables
const envVarsValid = checkEnvironmentVariables("API_PORT", "INFISICAL_TOKEN");
if (!envVarsValid) {
  process.exit(1);
}

const server = createServer({
  port: process.env.API_PORT || 3000,
  onLoaded: async () => {
    await initSecrets(process.env.INFISICAL_TOKEN!); // Load the infisical secrets

    const routeManager = new RouteManager();
    routeManager.addRoute(new ProxyRoute());

    server.all("*", (req, res) => {
      const route = routeManager.getRoute(req.path);
      if (route) {
        route.handle(req, res);
        return;
      }

      // Handle unknown routes
      res.json(RouteMessages.unknownRoute());
    });
  },
});
